@@ -15,7 +15,7 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 
-import logging
+from pof.logger import logger
 
 try:
     import black
@@ -24,12 +24,10 @@ try:
 except ImportError:
     BLACK_INSTALLED = False
 
-from pof.errors import PofError
-
 
 def black_format(src: str) -> str:
     """Format raw source code using black."""
     if not BLACK_INSTALLED:
-        logging.error("'black' is not installed, cannot format using it")
+        logger.error("'black' is not installed, cannot format using it")
         return src
     return black.format_str(src, mode=black.FileMode())
