@@ -15,12 +15,14 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 import io
-from base64 import b64decode  # noqa
 
 # to fix a problem "undefined b64decode" during exec
+from base64 import b64decode  # noqa
+
 from tokenize import generate_tokens, untokenize
 
 from pof.obfuscator import XORObfuscator
+from .utils import exec_capture
 
 source = """
 def main_function():
@@ -38,4 +40,5 @@ def test_XORObfuscator():
     tokens = XORObfuscator().obfuscate_tokens(tokens)
 
     out = untokenize(tokens)
-    exec(out)
+    captured_output = exec_capture(out, {"b64decode": b64decode})
+    assert captured_output == "Hello, world!\n"
